Function read_csv_gagne2014, file
  
  forward_function readcol, strtrim_multiple, is_number, strcoord
  
  ;Read the file, making sure to keep 2MASS and WISE information as strings for now
  readcol, file, number, name, companion, skmuse, ra, dec, spt, pmra, pmdec, epmra, epmdec, vrad, evrad, plx, eplx, memref,$
    sptref, pmref, vradref, plxref, tmassname, j, ej, h, eh, k, ek, wisename, w1, ew1, w2, ew2, w3, ew3, skmrejectreason,$
    comments, format='L,A,A,A,A,A,A,F,F,F,F,F,F,F,F,A,A,A,A,A,A,A,A,A,A,A,A,A,A,A,A,A,A,A,A,A', /preserve_null, skipline=1, $
    delimiter=','

  ;Trim any surviving space in data that will remain as string
  strtrim_multiple, name, companion, skmuse, ra, dec, spt, memref, sptref, pmref, vradref, plxref, tmassname, wisename, skmrejectreason, comments

  ;When wise information is not available, transform into NaNs
  g1 = where(~is_number(w1), ng1)
  if ng1 ne 0L then w1[g1] = 'NaN'
  g2 = where(~is_number(w2), ng2)
  if ng2 ne 0L then w2[g2] = 'NaN'
  g3 = where(~is_number(w3), ng3)
  if ng3 ne 0L then w3[g3] = 'NaN'
  eg1 = where(~is_number(ew1), neg1)
  if neg1 ne 0L then ew1[eg1] = 'NaN'
  eg2 = where(~is_number(ew2), neg2)
  if neg2 ne 0L then ew2[eg2] = 'NaN'
  eg3 = where(~is_number(ew3), neg3)
  if neg3 ne 0L then ew3[eg3] = 'NaN'

  ;Do the same with 2MASS
  gj = where(~is_number(J), ngj)
  if ngj ne 0L then J[gj] = 'NaN'
  gh = where(~is_number(H), ngh)
  if ngh ne 0L then H[gh] = 'NaN'
  gk = where(~is_number(K), ngk)
  if ngk ne 0L then K[gk] = 'NaN'
  egj = where(~is_number(eJ), negj)
  if negj ne 0L then eJ[egj] = 'NaN'
  egh = where(~is_number(eH), negh)
  if negh ne 0L then eH[egh] = 'NaN'
  egk = where(~is_number(eK), negk)
  if negk ne 0L then eK[egk] = 'NaN'

  ;Transform all these values to floating-point precision
  W1 = float(W1) & eW1 = float(eW1)
  W2 = float(W2) & eW2 = float(eW2)
  W3 = float(W3) & eW3 = float(eW3)
  J = float(J) & H = float(H) & K = float(K)
  eJ = float(eJ) & eH = float(eH) & eK = float(eK)

  ;Format RA & DEC

  ;Identify and repair cases with minute-precision RA or DEC
  bad = where(strpos(ra,'.') gt 3 and strpos(ra,'.') le 6L, nbad)
  splitra = strsplit(ra[bad],' ',/extract)
  if nbad eq 1L then splitra = list(splitra)
  for i=0L, nbad-1L do begin
    mini = float((splitra[i])[1])
    ra[bad[i]] = (splitra[i])[0L]+' '+strtrim(floor(mini),2L)+' '+strtrim(frac(mini)*60.,2L)
  endfor

  bad = where(strpos(dec,'.') gt 4 and strpos(dec,'.') le 7L, nbad)
  splitdec = strsplit(dec[bad],' ',/extract)
  if nbad eq 1L then splitdec = list(splitdec)
  for i=0L, nbad-1L do begin
    mini = float((splitdec[i])[1])
    dec[bad[i]] = (splitdec[i])[0L]+' '+strtrim(floor(mini),2L)+' '+strtrim(frac(mini)*60.,2L)
  endfor

  ;Repair any occurrence without a decimal point
  bad = where(strpos(ra,'.') eq -1L, nbad)
  if nbad ne 0L then ra[bad] += '.0'
  bad = where(strpos(dec,'.') eq -1L, nbad)
  if nbad ne 0L then dec[bad] += '.0'

  ;Then explode strings into 2D arrays
  nobj = n_elements(ra)
  nchar_ra = max(strlen(ra))
  nminchar_ra = min(strlen(ra))
  if nminchar_ra ne nchar_ra then $
    zeropatch_ra = strjoin(strarr(nchar_ra-nminchar_ra)+'0') else $
    zeropatch_ra = ''
  byte_ra = (byte(ra+replicate(zeropatch_ra,nobj)))[0L:nchar_ra-1L,*]
  exploded_ra = string(reform(byte_ra,1L,nchar_ra,nobj))

  nchar_dec = max(strlen(dec))
  nminchar_dec = min(strlen(dec))
  if nminchar_dec ne nchar_dec then $
    zeropatch_dec = strjoin(strarr(nchar_dec-nminchar_dec)+'0') else $
    zeropatch_dec = ''
  byte_dec = (byte(dec+replicate(zeropatch_dec,nobj)))[0L:nchar_dec-1L,*]
  exploded_dec = string(reform(byte_dec,1L,nchar_dec,nobj))
  
  ;Identify and replace spaces
  bad = where(exploded_ra eq ' ', nbad)
  if nbad ne 0L then exploded_ra[bad] = ':'
  bad = where(exploded_dec eq ' ', nbad)
  if nbad ne 0L then exploded_dec[bad] = ':'
  
  ;Recombine RA & DECs
  ra = strjoin(exploded_ra)
  dec = strjoin(exploded_dec)

  ;Create decimal versions of RA & DEC
  crd = strcoord(ra,dec,':')
  dra = crd[*,0L]
  ddec = crd[*,1L]
  
  ;Store all data into a single structure
  vars = ['number','name','companion','skmuse','ra','dec','dra','ddec','spt','pmra','epmra','pmdec','epmdec','vrad','evrad','plx','eplx','memref','sptref','pmref','vradref','plxref','tmassname','J','EJ','H','EH','K','EK','W1','EW1','W2','EW2','W3','EW3','SKMREJECTREASON','COMMENTS']
  void = execute('struc = str_array(vars, '+strjoin(vars,', ')+')')
  
  ;Return the structure
  return, struc
  
End